MethodChannelFlutterScreenguard class

An implementation of FlutterScreenguardPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
onScreenRecordingCaptured → Stream<Map<String, dynamic>>
iOS, Android stream for screen recording captured event Returns a Map with:
no setteroverride
onScreenshotCaptured → Stream<Map<String, dynamic>>
iOS, Android stream for screenshot captured event
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getScreenGuardLogs({required int maxCount}) → Future<List<Map<String, dynamic>>>
iOS, Android get screen guard logs
override
initSettings({bool? enableCapture = false, bool? enableRecord = false, bool? enableContentMultitask = false, bool? displayOverlay = false, bool? displayScreenguardOverlayAndroid = true, int? timeAfterResume = 1000, bool? getScreenshotPath = false, int? limitCaptureEvtCount = 0, bool? trackingLog = false}) → Future<void>
Initialize the screen guard with settings
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register({required Color color}) → Future<void>
activate a screenshot blocking with a color effect view (iOS 13+, Android 8+) color color of the background
override
registerWithBlurView({required num radius, String? localImagePath}) → Future<void>
iOS, Android activate a screenshot blocking with a blurred effect view (iOS 13+, Android 8+) radius radius
override
registerWithImage({required String uri, required double width, required double height, Color? color = Colors.black, Alignment? alignment, double? top, double? left, double? bottom, double? right}) → Future<void>
iOS 13+, Android 8+ activate a screenshot blocking with an image effect view color color of the background
override
registerWithoutEffect() → Future<void>
Android 5+ activate a screenshot blocking without any effect (blur, image, color)
override
toString() → String
A string representation of this object.
inherited
unregister() → Future<void>
unregister and deactivate all screenguard and listener Throws a PlatformException if there were technical problems on native side
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

alignments → const List<Alignment>