registerWithBlurView method

  1. @override
Future<void> registerWithBlurView({
  1. required num radius,
  2. String? localImagePath,
})
override

iOS, Android activate a screenshot blocking with a blurred effect view (iOS 13+, Android 8+) radius radius

Throws a PlatformException if there were technical problems on native side (e.g. lack of relevant hardware).

Implementation

@override
Future<void> registerWithBlurView({
  required num radius,
  String? localImagePath,
}) async {
  await methodChannel
      .invokeMethod<void>('activateShieldWithBlurView', <String, dynamic>{
    'radius': radius,
    'localImagePath': localImagePath,
  });
}