registerWithImage method

Future<void> registerWithImage({
  1. required String uri,
  2. required double width,
  3. required double height,
  4. Color? color = Colors.black,
  5. Alignment? alignment,
  6. double? top,
  7. double? left,
  8. double? bottom,
  9. double? right,
})

iOS 13+, Android 8+ activate a screenshot blocking with an image effect view color color of the background

uri (required) uri of the image

width (required) width of the image

height (required) height of the image

alignment Alignment of the image, default Alignment.center

Throws a PlatformException if there were technical problems on native side

Implementation

Future<void> registerWithImage({
  required String uri,
  required double width,
  required double height,
  Color? color = Colors.black,
  Alignment? alignment,
  double? top,
  double? left,
  double? bottom,
  double? right,
}) {
  throw UnimplementedError('register() has not been implemented.');
}