FlutterScreenguardPlatform class
abstract
Inheritance
Object
PlatformInterface
FlutterScreenguardPlatform
Implementers
Methods
getScreenGuardLogs ({required int maxCount })
→ Future <List <Map <String , dynamic > > >
iOS, Android get screen guard logs
initSettings ({bool ? enableCapture = false , bool ? enableRecord = false , bool ? enableContentMultitask = false , bool ? displayOverlay = false , bool ? displayScreenguardOverlayAndroid = true , int ? timeAfterResume = 1000 , bool ? getScreenshotPath = false , int ? limitCaptureEvtCount , bool ? trackingLog = false })
→ Future <void >
Initialize the screen guard with settings
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register ({required Color color })
→ Future <void >
activate a screenshot blocking with a color effect view (iOS 13+, Android 8+)
color color of the background
registerWithBlurView ({required num radius , String ? localImagePath })
→ Future <void >
iOS, Android activate a screenshot blocking with a blurred effect view (iOS 13+, Android 8+)
radius blur radius value number in between 15, 50, throws warning if smaller than 15 or bigger than 50,
registerWithImage ({required String uri , required double width , required double height , Color ? color = Colors.black , Alignment ? alignment , double ? top , double ? left , double ? bottom , double ? right })
→ Future <void >
iOS 13+, Android 8+ activate a screenshot blocking with an image effect view
color color of the background
registerWithoutEffect ()
→ Future <void >
Android 5+ activate a screenshot blocking without any effect (blur, image, color)
toString ()
→ String
A string representation of this object.
inherited
unregister ()
→ Future <void >
unregister and deactivate all screenguard and listener
Throws a PlatformException if there were technical problems on native side
flutter_screenguard 2.0.0