register method
activate a screenshot blocking with a color effect view (iOS 13+, Android 8+)
color color of the background
Throws a PlatformException if there were technical problems on native side
(e.g. lack of relevant hardware).
Implementation
Future<void> register({
required Color color,
}) {
throw UnimplementedError('register() has not been implemented.');
}