registerWithBlurView method
iOS, Android activate a screenshot blocking with a blurred effect view (iOS 13+, Android 8+)
radius blur radius value number in between 15, 50, throws warning if smaller than 15 or bigger than 50,
localImagePath Path to local image which is generated by Flutter,
Throws a PlatformException if there were technical problems on native side
(e.g. lack of relevant hardware).
Implementation
Future<void> registerWithBlurView({
required num radius,
String? localImagePath,
}) {
throw UnimplementedError(
'registerWithBlurView() has not been implemented.');
}