registerWithImage method
iOS 13+, Android 8+ activate a screenshot blocking with an image effect view
color color of the background
uri (required) uri of the image
width (required) width of the image
height (required) height of the image
alignment Alignment of the image, default Alignment.center
Throws a PlatformException if there were technical problems on native side
Implementation
Future<void> registerWithImage({
required String uri,
required double width,
required double height,
Color? color = Colors.black,
Alignment? alignment,
double? top,
double? left,
double? bottom,
double? right,
}) {
throw UnimplementedError('register() has not been implemented.');
}